@@ -97,10 +97,18 @@ class NIFSentence:
             print("[Error]: Sentence <"+self.uri+"> with out ini/fin predicate")
             return ""
         
+        
         s = ""
         if self.addAlwaysPositionsToUriInSentence:
-            s = standarURI(self.uri, ini, fin) + "\n        a nif:String , nif:Context  , nif:RFC5147String ;\n"
-        else: s = "<"+self.uri+">" + "\n        a nif:String , nif:Context  , nif:RFC5147String ;\n"
+            s = standarURI(self.uri, ini, fin) + "\n        a nif:String , nif:Context  , nif:RFC5147String ;\n" 
+        else: 
+            self.uri = self.uri.split("#")[0] 
+            
+            if "idsent" in passValues:
+                self.uri = self.uri + "_sentence"+ str(passValues["index_sent"])
+            s = "<"+self.uri+">" + "\n        a nif:String , nif:Context  , nif:RFC5147String ;\n"
+        
+        
         s = s + attr2nif(self.attr, set([]))
         s = s + "\n"
         
@@ -117,8 +125,10 @@ class NIFSentence:
 
         for idann in self.dictA:
             index = self.dictA[idann]
-            newPassedValues = {"sentIni": ini, "sentFin": fin}
+            newPassedValues = {"sentIni": ini, "sentFin": fin, "sentUri": self.uri}
             newPassedValues.update(passValues)
+            self.annotations[index].addAlwaysPositionsToUriInSentence = self.addAlwaysPositionsToUriInSentence
+            self.annotations[index].sentenceIniFin = [ini, fin]
             s = s + self.annotations[index].toString(newPassedValues)
             s = s + "\n"
         return s
